#ifndef MAINDIALOG_HPP
#define MAINDIALOG_HPP
#include "wxcrafter.hpp"

class MainDialog : public MainDialogBaseClass
{
public:
    MainDialog(wxWindow* parent);
    virtual ~MainDialog();
};
#endif // MAINDIALOG_HPP
