// set this to 1 if you don't want to use manifest resource (manifest resource
// is needed to enable visual styles on Windows XP - see docs/msw/winxp.txt
// for more information)
#define wxUSE_NO_MANIFEST 0

// To get DPI change events, we need to opt in into per monitor DPI support.
#define wxUSE_DPI_AWARE_MANIFEST 2

// this is not always needed but doesn't hurt (except making the executable
// very slightly larger): this file contains the standard icons, cursors, ...
#if !defined(__llvm__)
#include "wx/msw/wx.rc"
#endif
